==> perl-5.7.0.tar.gz: perl-5.7.0/uconfig.sh <==
#!/bin/sh
_a='.a'
_o='.o'
afs='false'
alignbytes='4'
apiversion='5.005'
archlib='/usr/local/lib/perl5/5.6/unknown'
archlibexp='/usr/local/lib/perl5/5.6/unknown'
archname='unknown'
bin='/usr/local/bin'
bincompat5005='define'
byteorder='12'
castflags='0'
charsize='1'
clocktype='clock_t'
cpp_stuff='42'
crosscompile='undef'
d_Gconvert='sprintf((b),"%.*g",(n),(x))'
d_SCNfldbl='undef'
d_PRIEUldbl='undef'
d_PRIFUldbl='undef'
d_PRIGUldbl='undef'
d_PRIXU64='undef'
d_PRId64='undef'
d_PRIeldbl='undef'
d_PRIfldbl='undef'
d_PRIgldbl='undef'
d_PRIi64='undef'
d_PRIo64='undef'
d_PRIu64='undef'
d_PRIx64='undef'
d_access='undef'
d_accessx='undef'
d_alarm='undef'
d_archlib='undef'
d_atolf='undef'
d_atoll='undef'
d_attribut='undef'
d_bcmp='undef'
d_bcopy='undef'
d_bincompat5005='undef'
d_bsd='undef'
d_bsdgetpgrp='undef'
d_bsdsetpgrp='undef'
d_bzero='undef'
d_casti32='undef'
d_castneg='undef'
d_charvspr='undef'
d_chown='undef'
d_chroot='undef'
d_chsize='undef'
d_closedir='undef'
d_const='undef'
d_crypt='undef'
d_csh='undef'
d_cuserid='undef'
d_dbl_dig='undef'
d_difftime='undef'
d_dirnamlen='undef'
d_dlerror='undef'
d_dlopen='undef'
d_dlsymun='undef'
d_dosuid='undef'
d_drand48proto='undef'
d_dup2='undef'
d_eaccess='undef'
d_endgrent='undef'
d_endhent='undef'
d_endnent='undef'
d_endpent='undef'
d_endpwent='undef'
d_endsent='undef'
d_endspent='undef'
d_eofnblk='undef'
d_eunice='undef'
d_fchmod='undef'
d_fchown='undef'
d_fcntl='undef'
d_fd_macros='undef'
d_fd_set='undef'
d_fds_bits='undef'
d_fgetpos='undef'
d_flexfnam='undef'
d_flock='undef'
d_fork='define'
d_fpathconf='undef'
d_fpos64_t='undef'
d_fs_data_s='undef'
d_fseeko='undef'
d_fsetpos='undef'
d_fstatfs='undef'
d_fstatvfs='undef'
d_ftello='undef'
d_ftime='undef'
d_getcwd='undef'
d_getgrent='undef'
d_getgrps='undef'
d_gethbyaddr='undef'
d_gethbyname='undef'
d_gethent='undef'
d_gethname='undef'
d_gethostprotos='undef'
d_getlogin='undef'
d_getmnt='undef'
d_getmntent='undef'
d_getnbyaddr='undef'
d_getnbyname='undef'
d_getnent='undef'
d_getnetprotos='undef'
d_getpbyname='undef'
d_getpbynumber='undef'
d_getpent='undef'
d_getpgid='undef'
d_getpgrp2='undef'
d_getpgrp='undef'
d_getppid='undef'
d_getprior='undef'
d_getprotoprotos='undef'
d_getpwent='undef'
d_getsbyname='undef'
d_getsbyport='undef'
d_getsent='undef'
d_getservprotos='undef'
d_getspent='undef'
d_getspnam='undef'
d_gettimeod='undef'
d_gnulibc='undef'
d_grpasswd='undef'
d_hasmntopt='undef'
d_htonl='undef'
d_iconv='undef'
d_index='undef'
d_inetaton='undef'
d_int64t='undef'
d_isascii='undef'
d_killpg='undef'
d_lchown='undef'
d_ldbl_dig='undef'
d_link='undef'
d_locconv='undef'
d_lockf='undef'
d_longdbl='undef'
d_longlong='undef'
d_lstat='undef'
d_mblen='undef'
d_mbstowcs='undef'
d_mbtowc='undef'
d_memchr='undef'
d_memcmp='undef'
d_memcpy='undef'
d_memmove='undef'
d_memset='undef'
d_mkdir='undef'
d_mkdtemp='undef'
d_mkfifo='undef'
d_mkstemp='undef'
d_mkstemps='undef'
d_mktime='undef'
d_mprotect='undef'
d_msg='undef'
d_msg_ctrunc='undef'
d_msg_dontroute='undef'
d_msg_oob='undef'
d_msg_peek='undef'
d_msg_proxy='undef'
d_msgctl='undef'
d_msgget='undef'
d_msgrcv='undef'
d_msgsnd='undef'
d_msync='undef'
d_munmap='undef'
d_mymalloc='undef'
d_nice='undef'
d_nv_preserves_uv='undef'
d_off64_t='undef'
d_old_pthread_create_joinable='undef'
d_oldpthreads='undef'
d_oldsock='undef'
d_open3='undef'
d_pathconf='undef'
d_pause='undef'
d_phostname='undef'
d_pipe='undef'
d_poll='undef'
d_portable='undef'
d_pthread_yield='undef'
d_pwage='undef'
d_pwchange='undef'
d_pwclass='undef'
d_pwcomment='undef'
d_pwexpire='undef'
d_pwgecos='undef'
d_pwpasswd='undef'
d_pwquota='undef'
d_quad='undef'
d_readdir='undef'
d_readlink='undef'
d_rename='undef'
d_rewinddir='undef'
d_rmdir='undef'
d_safebcpy='undef'
d_safemcpy='undef'
d_sanemcmp='undef'
d_sched_yield='undef'
d_scm_rights='undef'
d_seekdir='undef'
d_select='undef'
d_sem='undef'
d_semctl='undef'
d_semctl_semid_ds='undef'
d_semctl_semun='undef'
d_semget='undef'
d_semop='undef'
d_setegid='undef'
d_seteuid='undef'
d_setgrent='undef'
d_setgrps='undef'
d_sethent='undef'
d_setlinebuf='undef'
d_setlocale='undef'
d_setnent='undef'
d_setpent='undef'
d_setpgid='undef'
d_setpgrp2='undef'
d_setpgrp='undef'
d_setprior='undef'
d_setproctitle='undef'
d_setpwent='undef'
d_setregid='undef'
d_setresgid='undef'
d_setresuid='undef'
d_setreuid='undef'
d_setrgid='undef'
d_setruid='undef'
d_setsent='undef'
d_setsid='undef'
d_setspent='undef'
d_setvbuf='undef'
d_sfio='undef'
d_shm='undef'
d_shmat='undef'
d_shmatprototype='undef'
d_shmctl='undef'
d_shmdt='undef'
d_shmget='undef'
d_sigaction='undef'
d_sigsetjmp='undef'
d_socket='undef'
d_sockpair='undef'
d_socks5_init='undef'
d_sqrtl='undef'
d_statblks='undef'
d_statfs_f_flags='undef'
d_statfs_s='undef'
d_statvfs='undef'
d_stdio_cnt_lval='undef'
d_stdio_ptr_lval='undef'
d_stdio_stream_array='undef'
d_stdiobase='undef'
d_stdstdio='undef'
d_strchr='undef'
d_strcoll='undef'
d_strctcpy='undef'
d_strerrm='strerror(e)'
d_strerror='undef'
d_strtod='undef'
d_strtol='undef'
d_strtold='undef'
d_strtoll='undef'
d_strtoul='undef'
d_strtoull='undef'
d_strtouq='undef'
d_strxfrm='undef'
d_suidsafe='undef'
d_symlink='undef'
d_syscall='undef'
d_sysconf='undef'
d_sysernlst=''
d_syserrlst='undef'
d_system='undef'
d_tcgetpgrp='undef'
d_tcsetpgrp='undef'
d_telldir='undef'
d_telldirproto='undef'
d_time='undef'
d_times='undef'
d_truncate='undef'
d_tzname='undef'
d_umask='undef'
d_uname='undef'
d_union_semun='undef'
d_ustat='undef'
d_vendorbin='undef'
d_vendorlib='undef'
d_vfork='undef'
d_void_closedir='undef'
d_voidsig='undef'
d_voidtty=''
d_volatile='undef'
d_vprintf='define'
d_wait4='undef'
d_waitpid='undef'
d_wcstombs='undef'
d_wctomb='undef'
d_xenix='undef'
db_hashtype='u_int32_t'
db_prefixtype='size_t'
defvoidused=1
direntrytype='struct dirent'
doublesize=1
drand01="((rand() & 0x7FFF) / (double) ((unsigned long)1 << 15))"
eagain='EAGAIN'
ebcdic='undef'
fflushNULL='undef'
fflushall='undef'
firstmakefile='makefile'
fpossize='4'
fpostype=int
freetype=int
gidformat='"lu"'
gidsign='1'
gidsize='4'
gidtype=int
groupstype=int
h_fcntl='false'
h_sysfile='true'
i16size='2'
i16type='short'
i32size='4'
i32type='long'
i64size='8'
i64type='int64_t'
i8size='1'
i8type='char'
i_arpainet='undef'
i_bsdioctl=''
i_db='undef'
i_dbm='undef'
i_dirent='undef'
i_dld='undef'
i_dlfcn='undef'
i_fcntl='undef'
i_float='undef'
i_gdbm='undef'
i_grp='undef'
i_iconv='undef'
i_inttypes='undef'
i_libutil='undef'
i_limits='undef'
i_locale='undef'
i_machcthr='undef'
i_malloc='undef'
i_math='define'
i_memory='undef'
i_mntent='undef'
i_ndbm='undef'
i_netdb='undef'
i_neterrno='undef'
i_netinettcp='undef'
i_niin='undef'
i_poll='undef'
i_pthread='undef'
i_pwd='undef'
i_rpcsvcdbm='undef'
i_sfio='undef'
i_sgtty='undef'
i_shadow='undef'
i_socks='undef'
i_stdarg='define'
i_stddef='undef'
i_stdlib='undef'
i_string='define'
i_sysaccess='undef'
i_sysdir='undef'
i_sysfile='undef'
i_sysfilio='undef'
i_sysin='undef'
i_sysioctl='undef'
i_syslog='undef'
i_sysmount='undef'
i_sysndir='undef'
i_sysparam='undef'
i_sysresrc='undef'
i_syssecrt='undef'
i_sysselct='undef'
i_syssockio=''
i_sysstat='define'
i_sysstatfs='undef'
i_sysstatvfs='undef'
i_systime='undef'
i_systimek='undef'
i_systimes='undef'
i_systypes='undef'
i_sysuio='undef'
i_sysun='undef'
i_sysvfs='undef'
i_syswait='undef'
i_termio='undef'
i_termios='undef'
i_time='define'
i_unistd='undef'
i_ustat='undef'
i_utime='undef'
i_values='undef'
i_varargs='undef'
i_varhdr='stdarg.h'
i_vfork='undef'
ignore_versioned_solibs='y'
installstyle='lib/perl5'
installusrbinperl='undef'
intsize='4'
intsize=1
ivdformat='"ld"'
ivsize='4'
ivtype='long'
lib_ext='.a'
longdblsize=1
longlongsize=1
longsize=1
lseeksize=1
lseektype=int
malloctype='int*'
malloctype='void *'
modetype='mode_t'
modetype=int
multiarch='undef'
myarchname='unknown'
myuname='unknown'
netdb_hlen_type='int'
netdb_host_type='const char *'
netdb_name_type='const char *'
netdb_net_type='unsigned long'
nroff='nroff'
nveformat='"e"'
nvfformat='"f"'
nvgformat='"g"'
nvsize='8'
nvtype='double'
o_nonblock='O_NONBLOCK'
obj_ext='.o'
optimize='-O2'
orderlib='false'
osname='unknown'
phostname='hostname'
pidtype=int
pm_apiversion='5.005'
privlib='/usr/local/lib/perl5/5.6'
privlibexp='/usr/local/lib/perl5/5.6'
prototype='undef'
ptrsize=1
quadkind='4'
quadtype='int64_t'
randbits='48'
randfunc='drand48'
randseedtype='int'
rd_nodata='-1'
sPRIEUldbl='"llE"'
sPRIFUldbl='"llF"'
sPRIGUldbl='"llG"'
sPRIXU64='"LX"'
sPRId64='"Ld"'
sPRIeldbl='"lle"'
sPRIfldbl='"llf"'
sPRIgldbl='"llg"'
sPRIi64='"Li"'
sPRIo64='"Lo"'
sPRIu64='"Lu"'
sPRIx64='"Lx"'
sched_yield='sched_yield()'
scriptdir='/usr/local/bin'
scriptdirexp='/usr/local/bin'
seedfunc='srand'
selectminbits='32'
selecttype=int
shmattype='void *'
shortsize=1
sig_count='64'
sig_name_init='0'
sig_num_init='0'
signal_t=int
sizetype=int
sizesize=1
sSCNfldbl='"llf"'
ssizetype=int
stdchar=char
stdio_base='((fp)->_IO_read_base)'
stdio_bufsiz='((fp)->_IO_read_end - (fp)->_IO_read_base)'
stdio_cnt='((fp)->_IO_read_end - (fp)->_IO_read_ptr)'
stdio_filbuf=''
stdio_ptr='((fp)->_IO_read_ptr)'
stdio_stream_array=''
timetype=int
touch='touch'
u16size='2'
u16type='unsigned short'
u32size='4'
u32type='unsigned long'
u64size='8'
u64type='uint64_t'
u8size='1'
u8type='unsigned char'
uidformat='"lu"'
uidsign='1'
uidsize='4'
uidtype=int
uquadtype='uint64_t'
use5005threads='undef'
use64bits='undef'
usedl='undef'
useithreads='undef'
uselargefiles='undef'
uselongdouble='undef'
uselonglong='undef'
usemorebits='undef'
usemultiplicity='undef'
usemymalloc='n'
usenm='false'
useopcode='true'
useperlio='undef'
useposix='true'
usesfio='false'
useshrplib='false'
usesocks='undef'
usethreads='undef'
usevendorprefix='undef'
usevfork='false'
uvoformat='"lo"'
uvsize='4'
uvtype='unsigned long'
uvuformat='"lu"'
uvxformat='"lx"'
voidflags=1
xs_apiversion='5.005'
d_getfsstat='undef'
d_int64_t='undef'
d_lseekproto='undef'
d_madvise='undef'
d_mmap='undef'
use64bitint='undef'
use64bitall='undef'
d_vendorarch='undef'
d_vendorarch='undef'
i_ieeefp='undef'
i_sunmath='undef'
i_sysmode='undef'
i_sysutsname='undef'
d_frexpl='undef'
d_modfl='undef'
d_getespwnam='undef'
d_getprpwnam='undef'
d_isnan='undef'
d_isnanl='undef'
i_prot='undef'
d_perl_otherlibdirs='undef'
inc_version_list_init='NULL'
socksizetype='int'

==> perl-5.7.1.tar.gz: perl-5.7.1/uconfig.sh <==
#!/bin/sh
_a='.a'
_o='.o'
afs='false'
alignbytes='4'
apiversion='5.005'
archlib='/usr/local/lib/perl5/5.7/unknown'
archlibexp='/usr/local/lib/perl5/5.7/unknown'
archname='unknown'
bin='/usr/local/bin'
bincompat5005='define'
byteorder='12'
castflags='0'
charsize='1'
clocktype='clock_t'
cpp_stuff='42'
crosscompile='undef'
d_Gconvert='sprintf((b),"%.*g",(n),(x))'
d_PRIEUldbl='undef'
d_PRIFUldbl='undef'
d_PRIGUldbl='undef'
d_PRIXU64='undef'
d_PRId64='undef'
d_PRIeldbl='undef'
d_PRIfldbl='undef'
d_PRIgldbl='undef'
d_PRIi64='undef'
d_PRIo64='undef'
d_PRIu64='undef'
d_PRIx64='undef'
d_SCNfldbl='undef'
d__fwalk='undef'
d_access='undef'
d_accessx='undef'
d_alarm='undef'
d_archlib='undef'
d_atolf='undef'
d_atoll='undef'
d_attribut='undef'
d_bcmp='undef'
d_bcopy='undef'
d_bincompat5005='undef'
d_bsd='undef'
d_bsdgetpgrp='undef'
d_bsdsetpgrp='undef'
d_bzero='undef'
d_casti32='undef'
d_castneg='undef'
d_charvspr='undef'
d_chown='undef'
d_chroot='undef'
d_chsize='undef'
d_closedir='undef'
d_const='undef'
d_cmsghdr_s='undef'
d_crypt='undef'
d_csh='undef'
d_cuserid='undef'
d_dbl_dig='undef'
d_difftime='undef'
d_dirnamlen='undef'
d_dlerror='undef'
d_dlopen='undef'
d_dlsymun='undef'
d_dosuid='undef'
d_drand48proto='undef'
d_dup2='undef'
d_eaccess='undef'
d_endgrent='undef'
d_endhent='undef'
d_endnent='undef'
d_endpent='undef'
d_endpwent='undef'
d_endsent='undef'
d_eofnblk='undef'
d_eunice='undef'
d_fchmod='undef'
d_fchown='undef'
d_fcntl='undef'
d_fcntl_can_lock='undef'
d_fd_macros='undef'
d_fd_set='undef'
d_fds_bits='undef'
d_fgetpos='undef'
d_flexfnam='undef'
d_flock='undef'
d_fork='define'
d_fpathconf='undef'
d_fpos64_t='undef'
d_frexpl='undef'
d_fs_data_s='undef'
d_fseeko='undef'
d_fsetpos='undef'
d_fstatfs='undef'
d_fstatvfs='undef'
d_fsync='undef'
d_ftello='undef'
d_ftime='undef'
d_getcwd='undef'
d_getespwnam='undef'
d_getfsstat='undef'
d_getgrent='undef'
d_getgrps='undef'
d_gethbyaddr='undef'
d_gethbyname='undef'
d_gethent='undef'
d_gethname='undef'
d_gethostprotos='undef'
d_getitimer='undef'
d_getlogin='undef'
d_getmnt='undef'
d_getmntent='undef'
d_getnbyaddr='undef'
d_getnbyname='undef'
d_getnent='undef'
d_getnetprotos='undef'
d_getpagsz='undef'
d_getpbyname='undef'
d_getpbynumber='undef'
d_getpent='undef'
d_getpgid='undef'
d_getpgrp2='undef'
d_getpgrp='undef'
d_getppid='undef'
d_getprior='undef'
d_getprotoprotos='undef'
d_getprpwnam='undef'
d_getpwent='undef'
d_getsbyname='undef'
d_getsbyport='undef'
d_getsent='undef'
d_getservprotos='undef'
d_getspent='undef'
d_getspnam='undef'
d_gettimeod='undef'
d_gnulibc='undef'
d_grpasswd='undef'
d_hasmntopt='undef'
d_htonl='undef'
d_iconv='undef'
d_index='undef'
d_inetaton='undef'
d_int64_t='undef'
d_isascii='undef'
d_isnan='undef'
d_isnanl='undef'
d_killpg='undef'
d_lchown='undef'
d_ldbl_dig='undef'
d_link='undef'
d_locconv='undef'
d_lockf='undef'
d_longdbl='undef'
d_longlong='undef'
d_lseekproto='undef'
d_lstat='undef'
d_madvise='undef'
d_mblen='undef'
d_mbstowcs='undef'
d_mbtowc='undef'
d_memchr='undef'
d_memcmp='undef'
d_memcpy='undef'
d_memmove='undef'
d_memset='undef'
d_mkdir='undef'
d_mkdtemp='undef'
d_mkfifo='undef'
d_mkstemp='undef'
d_mkstemps='undef'
d_mktime='undef'
d_mmap='undef'
d_modfl='undef'
d_mprotect='undef'
d_msg='undef'
d_msg_ctrunc='undef'
d_msg_dontroute='undef'
d_msg_oob='undef'
d_msg_peek='undef'
d_msg_proxy='undef'
d_msgctl='undef'
d_msgget='undef'
d_msghdr_s='undef'
d_msgrcv='undef'
d_msgsnd='undef'
d_msync='undef'
d_munmap='undef'
d_mymalloc='undef'
d_nice='undef'
d_nv_preserves_uv='undef'
d_nv_preserves_uv_bits='0'
d_off64_t='undef'
d_old_pthread_create_joinable='undef'
d_oldpthreads='undef'
d_oldsock='undef'
d_open3='undef'
d_pathconf='undef'
d_pause='undef'
d_perl_otherlibdirs='undef'
d_phostname='undef'
d_pipe='undef'
d_poll='undef'
d_portable='undef'
d_pthread_yield='undef'
d_pwage='undef'
d_pwchange='undef'
d_pwclass='undef'
d_pwcomment='undef'
d_pwexpire='undef'
d_pwgecos='undef'
d_pwpasswd='undef'
d_pwquota='undef'
d_qgcvt='undef'
d_quad='undef'
d_readdir='undef'
d_readlink='undef'
d_readv='undef'
d_recvmsg='undef'
d_rename='undef'
d_rewinddir='undef'
d_rmdir='undef'
d_safebcpy='undef'
d_safemcpy='undef'
d_sanemcmp='undef'
d_sbrkproto='undef'
d_sched_yield='undef'
d_scm_rights='undef'
d_seekdir='undef'
d_select='undef'
d_sem='undef'
d_semctl='undef'
d_semctl_semid_ds='undef'
d_semctl_semun='undef'
d_semget='undef'
d_semop='undef'
d_sendmsg='undef'
d_setegid='undef'
d_seteuid='undef'
d_setgrent='undef'
d_setgrps='undef'
d_sethent='undef'
d_setitimer='undef'
d_setlinebuf='undef'
d_setlocale='undef'
d_setnent='undef'
d_setpent='undef'
d_setpgid='undef'
d_setpgrp2='undef'
d_setpgrp='undef'
d_setprior='undef'
d_setproctitle='undef'
d_setpwent='undef'
d_setregid='undef'
d_setresgid='undef'
d_setresuid='undef'
d_setreuid='undef'
d_setrgid='undef'
d_setruid='undef'
d_setsent='undef'
d_setsid='undef'
d_setvbuf='undef'
d_sfio='undef'
d_shm='undef'
d_shmat='undef'
d_shmatprototype='undef'
d_shmctl='undef'
d_shmdt='undef'
d_shmget='undef'
d_sigaction='undef'
d_sigprocmask='undef'
d_sigsetjmp='undef'
d_sockatmark='undef'
d_socket='undef'
d_socklen_t='undef'
d_sockpair='undef'
d_socks5_init='undef'
d_sqrtl='undef'
d_statblks='undef'
d_statfs_f_flags='undef'
d_statfs_s='undef'
d_statvfs='undef'
d_stdio_cnt_lval='undef'
d_stdio_ptr_lval='undef'
d_stdio_ptr_lval_nochange_cnt='undef'
d_stdio_ptr_lval_sets_cnt='undef'
d_stdio_stream_array='undef'
d_stdiobase='undef'
d_stdstdio='undef'
d_strchr='undef'
d_strcoll='undef'
d_strctcpy='undef'
d_strerrm='strerror(e)'
d_strerror='undef'
d_strtod='undef'
d_strtol='undef'
d_strtold='undef'
d_strtoll='undef'
d_strtoq='undef'
d_strtoul='undef'
d_strtoull='undef'
d_strtouq='undef'
d_strxfrm='undef'
d_suidsafe='undef'
d_symlink='undef'
d_syscall='undef'
d_sysconf='undef'
d_sysernlst=''
d_syserrlst='undef'
d_system='undef'
d_tcgetpgrp='undef'
d_tcsetpgrp='undef'
d_telldir='undef'
d_telldirproto='undef'
d_time='undef'
d_times='undef'
d_truncate='undef'
d_tzname='undef'
d_u32align='define'
d_ualarm='undef'
d_umask='undef'
d_uname='undef'
d_union_semun='undef'
d_usleep='undef'
d_ustat='undef'
d_vendorarch='undef'
d_vendorbin='undef'
d_vendorlib='undef'
d_vfork='undef'
d_void_closedir='undef'
d_voidsig='undef'
d_voidtty=''
d_volatile='undef'
d_vprintf='define'
d_wait4='undef'
d_waitpid='undef'
d_wcstombs='undef'
d_wctomb='undef'
d_writev='undef'
d_xenix='undef'
db_hashtype='u_int32_t'
db_prefixtype='size_t'
defvoidused=1
direntrytype='struct dirent'
doublesize=1
drand01="((rand() & 0x7FFF) / (double) ((unsigned long)1 << 15))"
eagain='EAGAIN'
ebcdic='undef'
fflushNULL='undef'
fflushall='undef'
firstmakefile='makefile'
fpossize='4'
fpostype=int
freetype=int
gidformat='"lu"'
gidsign='1'
gidsize='4'
gidtype=int
groupstype=int
h_fcntl='false'
h_sysfile='true'
i16size='2'
i16type='short'
i32size='4'
i32type='long'
i64size='8'
i64type='int64_t'
i8size='1'
i8type='char'
i_arpainet='undef'
i_bsdioctl=''
i_db='undef'
i_dbm='undef'
i_dirent='undef'
i_dld='undef'
i_dlfcn='undef'
i_fcntl='undef'
i_float='undef'
i_gdbm='undef'
i_grp='undef'
i_iconv='undef'
i_ieeefp='undef'
i_inttypes='undef'
i_libutil='undef'
i_limits='undef'
i_locale='undef'
i_machcthr='undef'
i_malloc='undef'
i_math='define'
i_memory='undef'
i_mntent='undef'
i_ndbm='undef'
i_netdb='undef'
i_neterrno='undef'
i_netinettcp='undef'
i_niin='undef'
i_poll='undef'
i_prot='undef'
i_pthread='undef'
i_pwd='undef'
i_rpcsvcdbm='undef'
i_sfio='undef'
i_sgtty='undef'
i_shadow='undef'
i_socks='undef'
i_stdarg='define'
i_stddef='undef'
i_stdlib='undef'
i_string='define'
i_sunmath='undef'
i_sysaccess='undef'
i_sysdir='undef'
i_sysfile='undef'
i_sysfilio='undef'
i_sysin='undef'
i_sysioctl='undef'
i_syslog='undef'
i_sysmman='undef'
i_sysmode='undef'
i_sysmount='undef'
i_sysndir='undef'
i_sysparam='undef'
i_sysresrc='undef'
i_syssecrt='undef'
i_sysselct='undef'
i_syssockio='undef'
i_sysstat='define'
i_sysstatfs='undef'
i_sysstatvfs='undef'
i_systime='undef'
i_systimek='undef'
i_systimes='undef'
i_systypes='undef'
i_sysuio='undef'
i_sysun='undef'
i_sysutsname='undef'
i_sysvfs='undef'
i_syswait='undef'
i_termio='undef'
i_termios='undef'
i_time='define'
i_unistd='undef'
i_ustat='undef'
i_utime='undef'
i_values='undef'
i_varargs='undef'
i_varhdr='stdarg.h'
i_vfork='undef'
ignore_versioned_solibs='y'
inc_version_list_init='NULL'
installstyle='lib/perl5'
installusrbinperl='undef'
intsize='4'
intsize=1
ivdformat='"ld"'
ivsize='4'
ivtype='long'
lib_ext='.a'
longdblsize=1
longlongsize=1
longsize=1
lseeksize=1
lseektype=int
malloctype='int*'
malloctype='void *'
modetype='mode_t'
modetype=int
multiarch='undef'
myarchname='unknown'
myuname='unknown'
need_va_copy='undef'
netdb_hlen_type='int'
netdb_host_type='const char *'
netdb_name_type='const char *'
netdb_net_type='unsigned long'
nroff='nroff'
nveformat='"e"'
nvfformat='"f"'
nvgformat='"g"'
nvsize='8'
nvtype='double'
o_nonblock='O_NONBLOCK'
obj_ext='.o'
optimize='-O2'
orderlib='false'
osname='unknown'
phostname='hostname'
pidtype=int
pm_apiversion='5.005'
privlib='/usr/local/lib/perl5/5.7'
privlibexp='/usr/local/lib/perl5/5.7'
prototype='undef'
ptrsize=1
quadkind='4'
quadtype='int64_t'
randbits='48'
randfunc='drand48'
randseedtype='int'
rd_nodata='-1'
sPRIEUldbl='"llE"'
sPRIFUldbl='"llF"'
sPRIGUldbl='"llG"'
sPRIXU64='"LX"'
sPRId64='"Ld"'
sPRIeldbl='"lle"'
sPRIfldbl='"llf"'
sPRIgldbl='"llg"'
sPRIi64='"Li"'
sPRIo64='"Lo"'
sPRIu64='"Lu"'
sPRIx64='"Lx"'
sSCNfldbl='"llf"'
sched_yield='sched_yield()'
scriptdir='/usr/local/bin'
scriptdirexp='/usr/local/bin'
seedfunc='srand'
selectminbits='32'
selecttype=int
shmattype='void *'
shortsize=1
sig_name_init='0'
sig_num_init='0'
sig_size='1'
signal_t=int
sizesize=1
sizetype=int
socksizetype='int'
ssizetype=int
stdchar=char
stdio_base='((fp)->_IO_read_base)'
stdio_bufsiz='((fp)->_IO_read_end - (fp)->_IO_read_base)'
stdio_cnt='((fp)->_IO_read_end - (fp)->_IO_read_ptr)'
stdio_filbuf=''
stdio_ptr='((fp)->_IO_read_ptr)'
stdio_stream_array=''
timetype=int
touch='touch'
u16size='2'
u16type='unsigned short'
u32size='4'
u32type='unsigned long'
u64size='8'
u64type='uint64_t'
u8size='1'
u8type='unsigned char'
uidformat='"lu"'
uidsign='1'
uidsize='4'
uidtype=int
uquadtype='uint64_t'
use5005threads='undef'
use64bitall='undef'
use64bitint='undef'
usedl='undef'
useithreads='undef'
uselargefiles='undef'
uselongdouble='undef'
usemorebits='undef'
usemultiplicity='undef'
usemymalloc='n'
usenm='false'
useopcode='true'
useperlio='undef'
useposix='true'
usesfio='false'
useshrplib='false'
usesocks='undef'
usethreads='undef'
usevendorprefix='undef'
usevfork='false'
uvoformat='"lo"'
uvsize='4'
uvtype='unsigned long'
uvuformat='"lu"'
uvxformat='"lx"'
uvXUformat='"lX"'
versiononly='undef'
voidflags=1
xs_apiversion='5.005'
